[kaffe] CVS kaffe (dalibor): Resynced with GNU Classpath: MessageFormat

Kaffe CVS cvs-commits at kaffe.org
Sun Jul 11 22:04:42 PDT 2004


PatchSet 4949 
Date: 2004/07/12 04:58:00
Author: dalibor
Branch: HEAD
Tag: (none) 
Log:
Resynced with GNU Classpath: MessageFormat

2004-07-11  Dalibor Topic  <robilad at kaffe.org>

        * libraries/javalib/java/text/MessageFormat.java:
        Resynced with GNU Classpath.

        2004-07-08  Ito Kazumitsu  <kaz at maczuka.gcd.org>

        * java/text/MessageFormat.java
        (formatInternal): Append {n} if argument n is unavailable.
        (format(Object, StringBuffer, FieldPosition)): This
        should be equivalent to format(Object[], StringBuffer, FieldPosition).

Members: 
	ChangeLog:1.2514->1.2515 
	libraries/javalib/java/text/MessageFormat.java:1.28->1.29 

Index: kaffe/ChangeLog
diff -u kaffe/ChangeLog:1.2514 kaffe/ChangeLog:1.2515
--- kaffe/ChangeLog:1.2514	Mon Jul 12 04:52:37 2004
+++ kaffe/ChangeLog	Mon Jul 12 04:58:00 2004
@@ -14,6 +14,18 @@
 
 2004-07-11  Dalibor Topic  <robilad at kaffe.org>
 
+	* libraries/javalib/java/text/MessageFormat.java:
+	Resynced with GNU Classpath.
+
+	2004-07-08  Ito Kazumitsu  <kaz at maczuka.gcd.org>
+
+        * java/text/MessageFormat.java
+        (formatInternal): Append "{n}" if argument n is unavailable.
+        (format(Object, StringBuffer, FieldPosition)): This
+        should be equivalent to format(Object[], StringBuffer, FieldPosition).
+
+2004-07-11  Dalibor Topic  <robilad at kaffe.org>
+
 	*  libraries/javalib/java/security/AccessControlContext.java,
 	libraries/javalib/java/security/VMAccessController.java:
 	Resynced with GNU Classpath.
Index: kaffe/libraries/javalib/java/text/MessageFormat.java
diff -u kaffe/libraries/javalib/java/text/MessageFormat.java:1.28 kaffe/libraries/javalib/java/text/MessageFormat.java:1.29
--- kaffe/libraries/javalib/java/text/MessageFormat.java:1.28	Mon Jun 21 22:01:30 2004
+++ kaffe/libraries/javalib/java/text/MessageFormat.java	Mon Jul 12 04:58:02 2004
@@ -1,5 +1,5 @@
 /* MessageFormat.java - Localized message formatting.
-   Copyright (C) 1999, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2004 Free Software Foundation, Inc.
 
 This file is part of GNU Classpath.
 
@@ -420,6 +420,7 @@
 	  unavailable = true;
 	else
 	  thisArg = arguments[elements[i].argNumber];
+
 	AttributedCharacterIterator iterator = null;
 
 	Format formatter = null;
@@ -503,17 +504,18 @@
   }
 
   /**
    * Returns the pattern with the formatted objects.
    * This is equivalent to format((Object[]) singleArg, appendBuf, fpos)
    *
    * @param singleArg The object to be formatted.
    * @param appendBuf The StringBuffer where the text is appened.
    * @param fpos A FieldPosition object (it is ignored).
    */
-  public final StringBuffer format (Object singleArg, StringBuffer appendBuf,
+  public final StringBuffer format (Object objectArray, StringBuffer appendBuf,
 				    FieldPosition fpos)
   {
-    return format((Object[]) singleArg, appendBuf, fpos);
+    return format ((Object[])objectArray, appendBuf, fpos);
   }
 
   /**
@@ -503,17 +504,18 @@
 
   /**
-   * Returns the pattern with the formatted objects.
-   * This is equivalent to format((Object[]) singleArg, appendBuf, fpos)
+   * Returns the pattern with the formatted objects.  The first argument
+   * must be a array of Objects.
+   * This is equivalent to format((Object[]) objectArray, appendBuf, fpos)
    *
@@ -503,17 +504,18 @@
    *
-   * @param singleArg The object to be formatted.
+   * @param objectArray The object array to be formatted.
    * @param appendBuf The StringBuffer where the text is appened.
    * @param fpos A FieldPosition object (it is ignored).




More information about the kaffe mailing list